pub struct LedgerStateOverride {
pub network_override: Option<Network>,
pub height_override: Option<Height>,
pub previous_block_hash_override: Option<Hash>,
pub network_upgrade_override: Option<NetworkUpgrade>,
pub transaction_version_override: Option<u32>,
pub transaction_has_valid_network_upgrade: bool,
pub always_has_coinbase: bool,
}Expand description
Overrides for arbitrary LedgerStates.
Fields
network_override: Option<Network>Use the given network instead of Mainnet
height_override: Option<Height>Every chain starts at this block. Single blocks have this height.
previous_block_hash_override: Option<Hash>Every chain starts with a block with this previous block hash. Single blocks have this previous block hash.
network_upgrade_override: Option<NetworkUpgrade>Regardless of tip height and network, every block has features from this network upgrade.
transaction_version_override: Option<u32>Regardless of tip height and network, every transaction is this version.
transaction_has_valid_network_upgrade: boolEvery V5 and later transaction has a valid network_upgrade field.
If false, zero or more transactions may have invalid network upgrades.
always_has_coinbase: boolEvery block has exactly one coinbase transaction. Transactions are always coinbase transactions.