#[non_exhaustive]pub struct LedgerState {
pub height: Height,
pub network: Network,
network_upgrade_override: Option<NetworkUpgrade>,
previous_block_hash_override: Option<Hash>,
transaction_version_override: Option<u32>,
transaction_has_valid_network_upgrade: bool,
pub(crate) has_coinbase: bool,
}Expand description
The configuration data for proptest when generating arbitrary chains
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.height: HeightThe height of the generated block, or the start height of the generated chain.
To get the network upgrade, use the network_upgrade method.
If network_upgrade_override is not set, the network upgrade is derived
from the height and network.
network: NetworkThe network to generate fake blocks for.
network_upgrade_override: Option<NetworkUpgrade>Overrides the network upgrade calculated from height and network.
To get the network upgrade, use the network_upgrade method.
previous_block_hash_override: Option<Hash>Overrides the previous block hashes in blocks generated by this ledger.
transaction_version_override: Option<u32>Regardless of tip height and network, every transaction is this version.
transaction_has_valid_network_upgrade: boolEvery V5 and later transaction has a valid network_upgrade field.
If false, zero or more transactions may have invalid network upgrades.
has_coinbase: boolGenerate coinbase transactions.
In a block or transaction vector, make the first transaction a coinbase transaction.
For an individual transaction, make the transaction a coinbase transaction.
Implementations
Sourceimpl LedgerState
impl LedgerState
Sourcepub fn default_strategy() -> BoxedStrategy<Self>
pub fn default_strategy() -> BoxedStrategy<Self>
Returns the default strategy for creating arbitrary LedgerStates.
Sourcepub fn no_override_strategy() -> BoxedStrategy<Self>
pub fn no_override_strategy() -> BoxedStrategy<Self>
Returns a strategy for creating arbitrary LedgerStates, without any
overrides.
Sourcepub fn network_upgrade_strategy(
network_upgrade_override: NetworkUpgrade,
transaction_version_override: impl Into<Option<u32>>,
transaction_has_valid_network_upgrade: bool,
) -> BoxedStrategy<Self>
pub fn network_upgrade_strategy( network_upgrade_override: NetworkUpgrade, transaction_version_override: impl Into<Option<u32>>, transaction_has_valid_network_upgrade: bool, ) -> BoxedStrategy<Self>
Returns a strategy for creating LedgerStates with features from
network_upgrade_override.
These features ignore the actual tip height and network.
Sourcepub fn coinbase_strategy(
network_upgrade_override: impl Into<Option<NetworkUpgrade>>,
transaction_version_override: impl Into<Option<u32>>,
transaction_has_valid_network_upgrade: bool,
) -> BoxedStrategy<Self>
pub fn coinbase_strategy( network_upgrade_override: impl Into<Option<NetworkUpgrade>>, transaction_version_override: impl Into<Option<u32>>, transaction_has_valid_network_upgrade: bool, ) -> BoxedStrategy<Self>
Returns a strategy for creating LedgerStates that always have coinbase
transactions.
Also applies network_upgrade_override, if present.
Sourcepub fn genesis_strategy(
network_override: impl Into<Option<Network>>,
network_upgrade_override: impl Into<Option<NetworkUpgrade>>,
transaction_version_override: impl Into<Option<u32>>,
transaction_has_valid_network_upgrade: bool,
) -> BoxedStrategy<Self>
pub fn genesis_strategy( network_override: impl Into<Option<Network>>, network_upgrade_override: impl Into<Option<NetworkUpgrade>>, transaction_version_override: impl Into<Option<u32>>, transaction_has_valid_network_upgrade: bool, ) -> BoxedStrategy<Self>
Returns a strategy for creating LedgerStates that start with a genesis
block.
These strategies also have coinbase transactions, and an optional network upgrade override.
Use the Genesis network upgrade to get a random genesis block, with
Zcash genesis features.
Sourcepub fn height_strategy(
height: Height,
network_upgrade_override: impl Into<Option<NetworkUpgrade>>,
transaction_version_override: impl Into<Option<u32>>,
transaction_has_valid_network_upgrade: bool,
) -> BoxedStrategy<Self>
pub fn height_strategy( height: Height, network_upgrade_override: impl Into<Option<NetworkUpgrade>>, transaction_version_override: impl Into<Option<u32>>, transaction_has_valid_network_upgrade: bool, ) -> BoxedStrategy<Self>
Returns a strategy for creating LedgerStates that start at height.
These strategies also have coinbase transactions, and an optional network upgrade override.
Sourcepub fn network_upgrade(&self) -> NetworkUpgrade
pub fn network_upgrade(&self) -> NetworkUpgrade
Returns the network upgrade for this ledger state.
If network_upgrade_override is set, it replaces the upgrade calculated
using height and network.
Sourcepub fn transaction_version_override(&self) -> Option<u32>
pub fn transaction_version_override(&self) -> Option<u32>
Returns the transaction version override.
Sourcepub fn transaction_has_valid_network_upgrade(&self) -> bool
pub fn transaction_has_valid_network_upgrade(&self) -> bool
Returns true if all transactions have valid network upgrade fields.
If false, some transactions have invalid network upgrades.